==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/QGpGuiTools/src/RegExpRowSelector.h <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2011-01-30
**  Copyright: 2011-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef REGEXPROWSELECTOR_H
#define REGEXPROWSELECTOR_H

#include <QtGui>
#if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
#include <QtWidgets>
#endif

#include <QGpCoreTools.h>

#include "QGpGuiToolsDLLExport.h"

namespace QGpGuiTools {

  class QGPGUITOOLS_EXPORT RegExpRowSelector : public QWidget
  {
    Q_OBJECT
  public:
    RegExpRowSelector(QWidget * parent=nullptr);
    ~RegExpRowSelector();

    void setView(QAbstractItemView * view);
  private slots:
    void select();
    void patternChanged();
  private:
    void select(const QModelIndex& parent, QRegExp& exp);

    QComboBox * _pattern;
    QToolButton * _button;
    QAbstractItemView * _view;
  };

} // namespace QGpGuiTools

#endif // REGEXPROWSELECTOR_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/QGpGuiTools/src/RegExpRowSelector.h <==
/***************************************************************************
**
**  This file is part of QGpGuiTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2011-01-30
**  Copyright: 2011-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef REGEXPROWSELECTOR_H
#define REGEXPROWSELECTOR_H

#include <QtGui>
#if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
#include <QtWidgets>
#endif

#include <QGpCoreTools.h>

#include "QGpGuiToolsDLLExport.h"

namespace QGpGuiTools {

  class QGPGUITOOLS_EXPORT RegExpRowSelector : public QWidget
  {
    Q_OBJECT
  public:
    RegExpRowSelector(QWidget * parent=nullptr);
    ~RegExpRowSelector();

    void setView(QAbstractItemView * view);
  private slots:
    void select();
    void patternChanged();
  private:
    void select(const QModelIndex& parent, QRegularExpression& exp);

    QComboBox * _pattern;
    QToolButton * _button;
    QAbstractItemView * _view;
  };

} // namespace QGpGuiTools

#endif // REGEXPROWSELECTOR_H
